qec\_lego\_bench.noises package
===============================

Submodules
----------

qec\_lego\_bench.noises.depolarize\_noise module
------------------------------------------------

.. automodule:: qec_lego_bench.noises.depolarize_noise
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.noises.flip\_noise module
------------------------------------------

.. automodule:: qec_lego_bench.noises.flip_noise
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.noises.no\_noise module
----------------------------------------

.. automodule:: qec_lego_bench.noises.no_noise
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.noises.noise module
------------------------------------

.. automodule:: qec_lego_bench.noises.noise
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: qec_lego_bench.noises
   :members:
   :undoc-members:
   :show-inheritance:
